# Add Business Capabilities
### On this page
  * [Introduction to Business Capabilities](https://help.sap.com/docs/leanix/ea/add-business-capabilities#introduction-to-business-capabilities)
  * [Required Attributes](https://help.sap.com/docs/leanix/ea/add-business-capabilities#required-attributes)
  * [Define Business Capabilities](https://help.sap.com/docs/leanix/ea/add-business-capabilities#define-business-capabilities)
  * [Add Business Capabilities](https://help.sap.com/docs/leanix/ea/add-business-capabilities#add-business-capabilities)
  * [Monitor Progress Using Metrics](https://help.sap.com/docs/leanix/ea/add-business-capabilities#monitor-progress-using-metrics)


Define and import an initial set of business capabilities into your workspace.
